@@ -1,4 +1,4 @@
-/*	$OpenBSD: tls13_lib.c,v 1.55 2020/11/16 18:55:15 jsing Exp $ */
+/*	$OpenBSD: tls13_lib.c,v 1.59 2021/04/07 21:48:23 tb Exp $ */
 /*
  * Copyright (c) 2018, 2019 Joel Sing <jsing@openbsd.org>
  * Copyright (c) 2019 Bob Beck <beck@openbsd.org>
@@ -147,7 +147,8 @@ tls13_alert_sent_cb(uint8_t alert_desc, void *arg)
 	}
 
 	/* All other alerts are treated as fatal in TLSv1.3. */
-	SSLerror(ctx->ssl, SSL_AD_REASON_OFFSET + alert_desc);
+	if (ctx->error.code == 0)
+		SSLerror(ctx->ssl, SSL_AD_REASON_OFFSET + alert_desc);
 }
 
 static void
@@ -223,7 +224,7 @@ tls13_legacy_ocsp_status_recv_cb(void *arg)
 static int
 tls13_phh_update_local_traffic_secret(struct tls13_ctx *ctx)
 {
-	struct tls13_secrets *secrets = ctx->hs->secrets;
+	struct tls13_secrets *secrets = ctx->hs->tls13.secrets;
 
 	if (ctx->mode == TLS13_HS_CLIENT)
 		return (tls13_update_client_traffic_secret(secrets) &&
@@ -237,7 +238,7 @@ tls13_phh_update_local_traffic_secret(struct tls13_ctx *ctx)
 static int
 tls13_phh_update_peer_traffic_secret(struct tls13_ctx *ctx)
 {
-	struct tls13_secrets *secrets = ctx->hs->secrets;
+	struct tls13_secrets *secrets = ctx->hs->tls13.secrets;
 
 	if (ctx->mode == TLS13_HS_CLIENT)
 		return (tls13_update_server_traffic_secret(secrets) &&
@@ -429,9 +430,9 @@ tls13_ctx_free(struct tls13_ctx *ctx)
 
 int
 tls13_cert_add(struct tls13_ctx *ctx, CBB *cbb, X509 *cert,
-    int(*build_extensions)(SSL *s, uint16_t msg_type, CBB *cbb))
+    int (*build_extensions)(SSL *s, uint16_t msg_type, CBB *cbb))
 {
-	CBB cert_data;
+	CBB cert_data, cert_exts;
 	uint8_t *data;
 	int cert_len;
 
@@ -448,7 +449,6 @@ tls13_cert_add(struct tls13_ctx *ctx, CBB *cbb, X509 *cert,
 		if (!build_extensions(ctx->ssl, SSL_TLSEXT_MSG_CT, cbb))
 			return 0;
 	} else {
-		CBB cert_exts;
 		if (!CBB_add_u16_length_prefixed(cbb, &cert_exts))
 			return 0;
 	}
@@ -504,16 +504,16 @@ tls13_synthetic_handshake_message(struct tls13_ctx *ctx)
 int
 tls13_clienthello_hash_init(struct tls13_ctx *ctx)
 {
-	if (ctx->hs->clienthello_md_ctx != NULL)
+	if (ctx->hs->tls13.clienthello_md_ctx != NULL)
 		return 0;
-	if ((ctx->hs->clienthello_md_ctx = EVP_MD_CTX_new()) == NULL)
+	if ((ctx->hs->tls13.clienthello_md_ctx = EVP_MD_CTX_new()) == NULL)
 		return 0;
-	if (!EVP_DigestInit_ex(ctx->hs->clienthello_md_ctx,
+	if (!EVP_DigestInit_ex(ctx->hs->tls13.clienthello_md_ctx,
 	    EVP_sha256(), NULL))
 		return 0;
 
-	if ((ctx->hs->clienthello_hash == NULL) &&
-	    (ctx->hs->clienthello_hash = calloc(1, EVP_MAX_MD_SIZE)) ==
+	if ((ctx->hs->tls13.clienthello_hash == NULL) &&
+	    (ctx->hs->tls13.clienthello_hash = calloc(1, EVP_MAX_MD_SIZE)) ==
 	    NULL)
 		return 0;
 
@@ -521,7 +521,7 @@ tls13_clienthello_hash_init(struct tls13_ctx *ctx)
 }
 
 void
-tls13_clienthello_hash_clear(struct ssl_handshake_tls13_st *hs)
+tls13_clienthello_hash_clear(struct ssl_handshake_tls13_st *hs) /* XXX */
 {
 	EVP_MD_CTX_free(hs->clienthello_md_ctx);
 	hs->clienthello_md_ctx = NULL;
@@ -533,7 +533,7 @@ int
 tls13_clienthello_hash_update_bytes(struct tls13_ctx *ctx, void *data,
     size_t len)
 {
-	return EVP_DigestUpdate(ctx->hs->clienthello_md_ctx, data, len);
+	return EVP_DigestUpdate(ctx->hs->tls13.clienthello_md_ctx, data, len);
 }
 
 int
@@ -546,12 +546,12 @@ tls13_clienthello_hash_update(struct tls13_ctx *ctx, CBS *cbs)
 int
 tls13_clienthello_hash_finalize(struct tls13_ctx *ctx)
 {
-	if (!EVP_DigestFinal_ex(ctx->hs->clienthello_md_ctx,
-	    ctx->hs->clienthello_hash,
-	    &ctx->hs->clienthello_hash_len))
+	if (!EVP_DigestFinal_ex(ctx->hs->tls13.clienthello_md_ctx,
+	    ctx->hs->tls13.clienthello_hash,
+	    &ctx->hs->tls13.clienthello_hash_len))
 		return 0;
-	EVP_MD_CTX_free(ctx->hs->clienthello_md_ctx);
-	ctx->hs->clienthello_md_ctx = NULL;
+	EVP_MD_CTX_free(ctx->hs->tls13.clienthello_md_ctx);
+	ctx->hs->tls13.clienthello_md_ctx = NULL;
 	return 1;
 }
 
@@ -561,18 +561,18 @@ tls13_clienthello_hash_validate(struct tls13_ctx *ctx)
 	unsigned char new_ch_hash[EVP_MAX_MD_SIZE];
 	unsigned int new_ch_hash_len;
 
-	if (ctx->hs->clienthello_hash == NULL)
+	if (ctx->hs->tls13.clienthello_hash == NULL)
 		return 0;
 
-	if (!EVP_DigestFinal_ex(ctx->hs->clienthello_md_ctx,
+	if (!EVP_DigestFinal_ex(ctx->hs->tls13.clienthello_md_ctx,
 	    new_ch_hash, &new_ch_hash_len))
 		return 0;
-	EVP_MD_CTX_free(ctx->hs->clienthello_md_ctx);
-	ctx->hs->clienthello_md_ctx = NULL;
+	EVP_MD_CTX_free(ctx->hs->tls13.clienthello_md_ctx);
+	ctx->hs->tls13.clienthello_md_ctx = NULL;
 
-	if (ctx->hs->clienthello_hash_len != new_ch_hash_len)
+	if (ctx->hs->tls13.clienthello_hash_len != new_ch_hash_len)
 		return 0;
-	if (memcmp(ctx->hs->clienthello_hash, new_ch_hash,
+	if (memcmp(ctx->hs->tls13.clienthello_hash, new_ch_hash,
 	    new_ch_hash_len) != 0)
 		return 0;
 
@@ -585,7 +585,7 @@ tls13_exporter(struct tls13_ctx *ctx, const uint8_t *label, size_t label_len,
     size_t out_len)
 {
 	struct tls13_secret context, export_out, export_secret;
-	struct tls13_secrets *secrets = ctx->hs->secrets;
+	struct tls13_secrets *secrets = ctx->hs->tls13.secrets;
 	EVP_MD_CTX *md_ctx = NULL;
 	unsigned int md_out_len;
 	int md_len;
@@ -608,13 +608,10 @@ tls13_exporter(struct tls13_ctx *ctx, const uint8_t *label, size_t label_len,
 	if (md_len <= 0 || md_len > EVP_MAX_MD_SIZE)
 		goto err;
 
-	if ((export_secret.data = calloc(1, md_len)) == NULL)
+	if (!tls13_secret_init(&export_secret, md_len))
 		goto err;
-	export_secret.len = md_len;
-
-	if ((context.data = calloc(1, md_len)) == NULL)
+	if (!tls13_secret_init(&context, md_len))
 		goto err;
-	context.len = md_len;
 
 	/* In TLSv1.3 no context is equivalent to an empty context. */
 	if (context_value == NULL) {
@@ -646,8 +643,8 @@ tls13_exporter(struct tls13_ctx *ctx, const uint8_t *label, size_t label_len,
 
  err:
 	EVP_MD_CTX_free(md_ctx);
-	freezero(context.data, context.len);
-	freezero(export_secret.data, export_secret.len);
+	tls13_secret_cleanup(&context);
+	tls13_secret_cleanup(&export_secret);
 
 	return ret;
 }
